@@ -1,16 +1,19 @@
 package Acme::Bleach;
-$VERSION = '1.12';
+our $VERSION = '1.150';
 my $tie = " \t"x8;
 sub whiten { local $_ = unpack "b*", pop; tr/01/ \t/; s/(.{9})/$1\n/g; $tie.$_ }
 sub brighten { local $_ = pop; s/^$tie|[^ \t]//g; tr/ \t/01/; pack "b*", $_ }
 sub dirty { $_[0] =~ /\S/ }
 sub dress { $_[0] =~ /^$tie/ }
 open 0 or print "Can't rebleach '$0'\n" and exit;
-(my $shirt = join "", <0>) =~ s/.*^\s*use\s+Acme::Bleach\s*;\n//sm;
+(my $shirt = join "", <0>) =~ s/(.*)^\s*use\s+Acme::Bleach\s*;\n//sm;
+my $coat = $1;
+my $pressed = '#line ' . ("$coat\n" =~ tr/\n/\n/) . ' ' . (caller)[1] . "\n";
 local $SIG{__WARN__} = \&dirty;
-do {eval brighten $shirt; exit} unless dirty $shirt && not dress $shirt;
+do {eval $coat . brighten $shirt; print STDERR $@ if $@; exit}
+    unless dirty $shirt && not dress $shirt;
 open 0, ">$0" or print "Cannot bleach '$0'\n" and exit;
-print {0} "use Acme::Bleach;\n", whiten $shirt and exit;
+print {0} "${coat}use Acme::Bleach;\n", whiten $pressed.$shirt and exit;
 __END__
 
 =head1 NAME
@@ -19,9 +22,9 @@ Acme::Bleach - For I<really> clean programs
 
 =head1 SYNOPSIS
 
-	use Acme::Bleach;
+    use Acme::Bleach;
 
-	print "Hello world";
+    print "Hello world";
 
 =head1 DESCRIPTION
 
@@ -30,29 +33,27 @@ removes all the unsightly printable characters from your source file.
 The code continues to work exactly as it did before, but now it
 looks like this:
 
-	use Acme::Bleach;
-											     
-					
-					  
-							
-					
-				
-			 
-			 
-					  
-					   
-								
-				     
-						
-								
-						
-					 
-				  
-						
-						 
-					
-					 
-	   
+    use Acme::Bleach;
+     	 	 	 	 	 	 	 	 	 	     
+       			  	
+      			 	  
+    	 		  			
+     		   	 	
+    		      	
+       	   	 
+        	  	 
+    	 	  		  
+     		 		   
+    		 		 			
+    	 		     
+     	  			 	
+    		 				 	
+    	  	  			
+       		 		 
+      	  		  
+    	   	  		
+     			   	 
+    	    
 
 =head1 DIAGNOSTICS
 
@@ -66,6 +67,8 @@ Acme::Bleach could not access the source file to modify it.
 
 Acme::Bleach could not access the source file to execute it.
 
+=back 
+
 =head1 SEE ALSO
 
 http://www.templetons.com/tech/proletext.html
@@ -80,3 +83,4 @@ Damian Conway (as if you couldn't guess)
  This module is free software. It may be used, redistributed
 and/or modified under the terms of the Perl Artistic License
      (see http://www.perl.com/perl/misc/Artistic.html)
+
